"use strict";
/**
 * @athenna/artisan
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Build = void 0;
const utils_1 = require("@secjs/utils");
const artisan_1 = require("@athenna/artisan");
class Build extends artisan_1.Command {
    constructor() {
        super(...arguments);
        /**
         * The name and signature of the console command.
         */
        this.signature = 'build';
        /**
         * The console command description.
         */
        this.description = 'Compile project from Typescript to Javascript.';
    }
    /**
     * Set additional flags in the commander instance.
     * This method is executed when registering your command.
     *
     * @return {void}
     */
    addFlags(commander) {
        return commander;
    }
    /**
     * Execute the console command.
     *
     * @return {Promise<void>}
     */
    async handle(_, commander) {
        this.simpleLog('[ BUILDING PROJECT ]', 'rmNewLineStart', 'bold', 'green');
        try {
            const rimrafPath = utils_1.Path.noBuild().pwd('node_modules/.bin/rimraf');
            let tscPath = utils_1.Path.noBuild().pwd('node_modules/.bin/tsc');
            const tscArgs = commander.args.join(' ');
            if (tscArgs) {
                tscPath = tscPath.concat(` ${tscArgs}`);
            }
            await this.execCommand(`${rimrafPath} dist`);
            await this.execCommand(tscPath);
            this.success('Built successfully.');
        }
        catch (error) {
            this.error('Failed to build project.');
        }
    }
}
exports.Build = Build;
